@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2013 by Daniel Nicoletti                           *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,8 +23,6 @@
 
 #include "Debug.h"
 
-#include <QStringBuilder>
-
 KIppRequest::KIppRequest() :
     d_ptr(new KIppRequestPrivate)
 {
@@ -36,7 +34,7 @@ KIppRequest::KIppRequest(const KIppRequest &other) :
     *this = other;
 }
 
-KIppRequest::KIppRequest(ipp_op_t operation, const char *resource, const QString &filename) :
+KIppRequest::KIppRequest(ipp_op_t operation, const QString &resource, const QString &filename) :
     d_ptr(new KIppRequestPrivate)
 {
     Q_D(KIppRequest);
@@ -46,13 +44,12 @@ KIppRequest::KIppRequest(ipp_op_t operation, const char *resource, const QString
     d->filename = filename;
 
     // send our user name on the request too
-    addString(IPP_TAG_OPERATION, IPP_TAG_NAME, KCUPS_REQUESTING_USER_NAME, cupsUser());
+    addString(IPP_TAG_OPERATION, IPP_TAG_NAME, QLatin1String(KCUPS_REQUESTING_USER_NAME), QString::fromUtf8(cupsUser()));
 }
 
 KIppRequest::~KIppRequest()
 {
-    Q_D(KIppRequest);
-    delete d;
+    delete d_ptr;
 }
 
 ipp_op_t KIppRequest::operation() const
@@ -82,9 +79,9 @@ ipp_t *KIppRequest::sendIppRequest() const
     d->addRawRequestsToIpp(request);
 
     if (d->filename.isNull()) {
-        return cupsDoRequest(CUPS_HTTP_DEFAULT, request, d->resource.toUtf8());
+        return cupsDoRequest(CUPS_HTTP_DEFAULT, request, qUtf8Printable(d->resource));
     } else {
-        return cupsDoFileRequest(CUPS_HTTP_DEFAULT, request, d->resource.toUtf8(), d->filename.toUtf8());
+        return cupsDoFileRequest(CUPS_HTTP_DEFAULT, request, qUtf8Printable(d->resource), qUtf8Printable(d->filename));
     }
 }
 
@@ -92,36 +89,36 @@ void KIppRequest::addString(ipp_tag_t group, ipp_tag_t valueTag, const QString &
 {
     Q_D(KIppRequest);
 
-    d->addRequest(group, valueTag, name.toUtf8(), value);
+    d->addRequest(group, valueTag, name, value);
 }
 
 void KIppRequest::addStringList(ipp_tag_t group, ipp_tag_t valueTag, const QString &name, const QStringList &value)
 {
     Q_D(KIppRequest);
 
-    d->addRequest(group, valueTag, name.toUtf8(), value);
+    d->addRequest(group, valueTag, name, value);
 }
 
 void KIppRequest::addInteger(ipp_tag_t group, ipp_tag_t valueTag, const QString &name, int value)
 {
     Q_D(KIppRequest);
 
-    d->addRequest(group, valueTag, name.toUtf8(), value);
+    d->addRequest(group, valueTag, name, value);
 }
 
 void KIppRequest::addBoolean(ipp_tag_t group, const QString &name, bool value)
 {
     Q_D(KIppRequest);
 
-    d->addRequest(group, IPP_TAG_ZERO, name.toUtf8(), value);
+    d->addRequest(group, IPP_TAG_ZERO, name, value);
 }
 
 void KIppRequest::addVariantValues(const QVariantHash &values)
 {
-    QVariantHash::ConstIterator i = values.constBegin();
+    auto i = values.constBegin();
     while (i != values.constEnd()) {
-        QString key = i.key();
-        QVariant value = i.value();
+        const QString &key = i.key();
+        const QVariant &value = i.value();
         switch (value.type()) {
         case QVariant::Bool:
             // Still in use at add-printer/PageAddPrinter.cpp
@@ -177,7 +174,7 @@ void KIppRequest::addVariantValues(const QVariantHash &values)
 void KIppRequest::addPrinterUri(const QString &printerName, bool isClass)
 {
     QString uri = assembleUrif(printerName, isClass);
-    addString(IPP_TAG_OPERATION, IPP_TAG_URI, KCUPS_PRINTER_URI, uri);
+    addString(IPP_TAG_OPERATION, IPP_TAG_URI, QLatin1String(KCUPS_PRINTER_URI), uri);
 }
 
 QString KIppRequest::assembleUrif(const QString &name, bool isClass)
@@ -186,14 +183,14 @@ QString KIppRequest::assembleUrif(const QString &name, bool isClass)
 
     QString destination;
     if (isClass) {
-        destination = QLatin1String("/classes/") % name;
+        destination = QLatin1String("/classes/") + name;
     } else {
-        destination = QLatin1String("/printers/") % name;
+        destination = QLatin1String("/printers/") + name;
     }
 
     httpAssembleURIf(HTTP_URI_CODING_ALL, uri, sizeof(uri), "ipp", cupsUser(), "localhost",
-                     ippPort(), destination.toUtf8());
-    return uri;
+                     ippPort(), destination.toUtf8().constData());
+    return QString::fromLatin1(uri);
 }
 
 KIppRequest &KIppRequest::operator =(const KIppRequest &other)
@@ -221,14 +218,17 @@ void KIppRequestPrivate::addRequest(ipp_tag_t group, ipp_tag_t valueTag, const Q
 void KIppRequestPrivate::addRawRequestsToIpp(ipp_t *ipp) const
 {
     // sort the values as CUPS requires it
-    qSort(rawRequests.begin(), rawRequests.end(), rawRequestGroupLessThan);
+    std::sort(rawRequests.begin(), rawRequests.end(), [] (const KCupsRawRequest &a, const KCupsRawRequest &b) {
+        return a.group < b.group;
+    });
 
-    foreach (const KCupsRawRequest &request, rawRequests) {
+    const QList<KCupsRawRequest> &requests = rawRequests;
+    for (const KCupsRawRequest &request :requests) {
         switch (request.value.type()) {
         case QVariant::Bool:
             ippAddBoolean(ipp,
                           request.group,
-                          request.name.toUtf8(),
+                          request.name.toUtf8().constData(),
                           request.value.toBool());
             break;
         case QVariant::Int:
@@ -236,16 +236,16 @@ void KIppRequestPrivate::addRawRequestsToIpp(ipp_t *ipp) const
             ippAddInteger(ipp,
                           request.group,
                           request.valueTag,
-                          request.name.toUtf8(),
+                          request.name.toUtf8().constData(),
                           request.value.toInt());
             break;
         case QVariant::String:
             ippAddString(ipp,
                          request.group,
                          request.valueTag,
-                         request.name.toUtf8(),
+                         request.name.toUtf8().constData(),
                          "utf-8",
-                         request.value.toString().toUtf8());
+                         request.value.toString().toUtf8().constData());
             break;
         case QVariant::StringList:
         {
@@ -256,7 +256,7 @@ void KIppRequestPrivate::addRawRequestsToIpp(ipp_t *ipp) const
             ippAddStrings(ipp,
                           request.group,
                           request.valueTag,
-                          request.name.toUtf8(),
+                          request.name.toUtf8().constData(),
                           list.size(),
                           "utf-8",
                           values);
